@@ -1,8 +1,8 @@
 /*
 **  OSSP sio - Stream I/O
-**  Copyright (c) 2002-2003 Cable & Wireless Deutschland <http://www.cw.com/de/>
-**  Copyright (c) 2002-2003 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2005 Cable & Wireless <http://www.cw.com/>
+**  Copyright (c) 2002-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2002-2005 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of OSSP sio, a layered stream I/O library
 **  which can be found at http://www.ossp.org/pkg/lib/sio/.
@@ -32,13 +32,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
-#ifndef SIZE_T_MAX
-#define SIZE_T_MAX UINT_MAX
-#endif
 
 #include "al.h"
 #include "sio.h"
 
+#ifndef SIZE_T_MAX
+#define SIZE_T_MAX (((((size_t)1 << ((sizeof(size_t) * 8) - 1)) - 1) << 1) + 1)
+#endif
+
 typedef struct {
     sio_t      *upstream;
     al_label_t  my_data_label;
