@@ -1,8 +1,8 @@
 /*
 **  OSSP sio - Stream I/O
-**  Copyright (c) 2002-2003 Cable & Wireless Deutschland <http://www.cw.com/de/>
-**  Copyright (c) 2002-2003 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2005 Cable & Wireless <http://www.cw.com/>
+**  Copyright (c) 2002-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2002-2005 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of OSSP sio, a layered stream I/O library
 **  which can be found at http://www.ossp.org/pkg/lib/sio/.
@@ -153,9 +153,17 @@ void session(ts_test_t *_t, func client, func server, int duplex)
         (*client)(_t, pd[0], wcount);
         close(pd[0]);
         waitpid(child, &status, 0);
-        if (status != 0) {
-            ts_test_fail(TS_CTX, "child returned status %08lx\n",
-                status);
+        if (WIFEXITED(status) && WEXITSTATUS(status) != 0) {
+            ts_test_fail(TS_CTX, "child terminated through exit with return code %d\n",
+                WEXITSTATUS(status));
+        }
+        else if (WIFSIGNALED(status)) {
+            ts_test_fail(TS_CTX, "child terminated through signal %d%s\n",
+                WTERMSIG(status), WCOREDUMP(status) ? " (core dump written)" : "");
+        }
+        else if (WIFSTOPPED(status)) {
+            ts_test_fail(TS_CTX, "child stopped through signal %d%s\n",
+                WSTOPSIG(status));
         }
     }
 }
@@ -1137,9 +1145,17 @@ TS_TEST(test_sio_sa)
         test_sio_sa_read(_t, sa_client, wcount);
         rc = sa_shutdown(sa_server, "r");
         waitpid(child, &status, 0);
-        if (status != 0) {
-            ts_test_fail(TS_CTX, "child returned status %08lx\n",
-                status);
+        if (WIFEXITED(status) && WEXITSTATUS(status) != 0) {
+            ts_test_fail(TS_CTX, "child terminated through exit with return code %d\n",
+                WEXITSTATUS(status));
+        }
+        else if (WIFSIGNALED(status)) {
+            ts_test_fail(TS_CTX, "child terminated through signal %d%s\n",
+                WTERMSIG(status), WCOREDUMP(status) ? " (core dump written)" : "");
+        }
+        else if (WIFSTOPPED(status)) {
+            ts_test_fail(TS_CTX, "child stopped through signal %d%s\n",
+                WSTOPSIG(status));
         }
     }
 
